import { Construct, IConstruct } from 'constructs';
import { ApiObject } from './api-object';
/**
 * @experimental
 */
export interface ChartProps {
    /**
     * (experimental) The default namespace for all objects defined in this chart (directly or indirectly).
     *
     * This namespace will only apply to objects that don't have a
     * `namespace` explicitly defined for them.
     *
     * @default - no namespace is synthesized (usually this implies "default")
     * @experimental
     */
    readonly namespace?: string;
    /**
     * (experimental) Labels to apply to all resources in this chart.
     *
     * @default - no common labels
     * @experimental
     */
    readonly labels?: {
        [name: string]: string;
    };
}
/**
 * @experimental
 */
export declare class Chart extends Construct {
    /**
     * (experimental) Finds the chart in which a node is defined.
     *
     * @param c a construct node.
     * @experimental
     */
    static of(c: IConstruct): Chart;
    /**
     * (experimental) The default namespace for all objects in this chart.
     *
     * @experimental
     */
    readonly namespace?: string;
    /**
     * Chart-level labels.
     */
    private readonly _labels?;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props?: ChartProps);
    /**
     * (experimental) Labels applied to all resources in this chart.
     *
     * This is an immutable copy.
     *
     * @experimental
     */
    get labels(): {
        [name: string]: string;
    };
    /**
     * (experimental) Generates a app-unique name for an object given it's construct node path.
     *
     * Different resource types may have different constraints on names
     * (`metadata.name`). The previous version of the name generator was
     * compatible with DNS_SUBDOMAIN but not with DNS_LABEL.
     *
     * For example, `Deployment` names must comply with DNS_SUBDOMAIN while
     * `Service` names must comply with DNS_LABEL.
     *
     * Since there is no formal specification for this, the default name
     * generation scheme for kubernetes objects in cdk8s was changed to DNS_LABEL,
     * since it’s the common denominator for all kubernetes resources
     * (supposedly).
     *
     * You can override this method if you wish to customize object names at the
     * chart level.
     *
     * @param apiObject The API object to generate a name for.
     * @experimental
     */
    generateObjectName(apiObject: ApiObject): string;
    /**
     * (experimental) Create a dependency between this Chart and other constructs.
     *
     * These can be other ApiObjects, Charts, or custom.
     *
     * @param dependencies the dependencies to add.
     * @experimental
     */
    addDependency(...dependencies: IConstruct[]): void;
    /**
     * (experimental) Renders this chart to a set of Kubernetes JSON resources.
     *
     * @returns array of resource manifests
     * @experimental
     */
    toJson(): any[];
}
